summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--accessibility/inc/accessibility/standard/vclxaccessiblebox.hxx2
-rw-r--r--extras/source/glade/makewidgetgroup.xslt2
-rw-r--r--include/sfx2/titledockwin.hxx2
-rw-r--r--sd/inc/Outliner.hxx8
-rw-r--r--sd/source/ui/annotations/annotationmanager.cxx2
-rw-r--r--sd/source/ui/inc/PreviewRenderer.hxx2
-rw-r--r--sd/source/ui/inc/ViewShell.hxx2
-rw-r--r--sd/source/ui/inc/Window.hxx2
-rw-r--r--sd/source/ui/inc/taskpane/ControlContainer.hxx4
-rw-r--r--sd/source/ui/inc/taskpane/ScrollPanel.hxx2
-rw-r--r--sd/source/ui/inc/taskpane/SubToolPanel.hxx4
-rw-r--r--sd/source/ui/sidebar/MasterPageContainer.cxx2
-rw-r--r--sd/source/ui/slidesorter/controller/SlsFocusManager.cxx4
-rw-r--r--sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx6
-rw-r--r--sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx2
-rw-r--r--sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx2
-rw-r--r--sd/source/ui/tools/PreviewRenderer.cxx4
-rw-r--r--sd/source/ui/view/Outliner.cxx16
-rw-r--r--sw/source/filter/html/wrthtml.cxx2
-rw-r--r--toolkit/test/accessibility/Canvas.java2
20 files changed, 36 insertions, 36 deletions
diff --git a/accessibility/inc/accessibility/standard/vclxaccessiblebox.hxx b/accessibility/inc/accessibility/standard/vclxaccessiblebox.hxx
index 2dda64128aca..cfd18b2ea28f 100644
--- a/accessibility/inc/accessibility/standard/vclxaccessiblebox.hxx
+++ b/accessibility/inc/accessibility/standard/vclxaccessiblebox.hxx
@@ -165,7 +165,7 @@ protected:
/** This flag specifies whether an object has a list as child regardless
of whether that child being currently instantiated or not. This
flag is always true in the current implementation because the list
- child is just another wrapper arround this object and thus has the
+ child is just another wrapper around this object and thus has the
same life time.
*/
bool m_bHasListChild;
diff --git a/extras/source/glade/makewidgetgroup.xslt b/extras/source/glade/makewidgetgroup.xslt
index c7d97d70822e..db2dcedc529d 100644
--- a/extras/source/glade/makewidgetgroup.xslt
+++ b/extras/source/glade/makewidgetgroup.xslt
@@ -19,7 +19,7 @@
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" version="1.0" encoding="UTF-8"/>
- <!-- work arround apparently broken output indenting in libxslt -->
+ <!-- work around apparently broken output indenting in libxslt -->
<xsl:param name="indent" select="' '"/>
<xsl:template match="/glade-catalog">
diff --git a/include/sfx2/titledockwin.hxx b/include/sfx2/titledockwin.hxx
index c27948a1c2c9..0b1f4dc5ec77 100644
--- a/include/sfx2/titledockwin.hxx
+++ b/include/sfx2/titledockwin.hxx
@@ -135,7 +135,7 @@ namespace sfx2
Link m_aEndDockingHdl;
- /** The border that is painted arround the inner window. The bevel
+ /** The border that is painted around the inner window. The bevel
shadow lines are part of the border, so where the border is 0 no
such line is painted.
*/
diff --git a/sd/source/ui/annotations/annotationmanager.cxx b/sd/source/ui/annotations/annotationmanager.cxx
index 730ab2b703a6..aa94bdda6c88 100644
--- a/sd/source/ui/annotations/annotationmanager.cxx
+++ b/sd/source/ui/annotations/annotationmanager.cxx
@@ -728,7 +728,7 @@ void AnnotationManagerImpl::SelectNextAnnotation(bool bForeward)
else
nStringId = bImpress ? STR_ANNOTATION_WRAP_BACKWARD : STR_ANNOTATION_WRAP_BACKWARD_DRAW;
- // Pop up question box that asks the user whether to wrap arround.
+ // Pop up question box that asks the user whether to wrap around.
// The dialog is made modal with respect to the whole application.
QueryBox aQuestionBox ( NULL, (WB_YES_NO | WB_DEF_YES), SD_RESSTR(nStringId));
aQuestionBox.SetImage (QueryBox::GetStandardImage());
diff --git a/sd/source/ui/inc/PreviewRenderer.hxx b/sd/source/ui/inc/PreviewRenderer.hxx
index 2f2755bf274b..d97b3223fca3 100644
--- a/sd/source/ui/inc/PreviewRenderer.hxx
+++ b/sd/source/ui/inc/PreviewRenderer.hxx
@@ -134,7 +134,7 @@ private:
const Color maFrameColor;
const bool mbHasFrame;
static const int snSubstitutionTextSize;
- // Width of the frame that is painted arround the preview.
+ // Width of the frame that is painted around the preview.
static const int snFrameWidth;
bool Initialize (
diff --git a/sd/source/ui/inc/ViewShell.hxx b/sd/source/ui/inc/ViewShell.hxx
index 02462db7ff7e..abd4d2b0acd2 100644
--- a/sd/source/ui/inc/ViewShell.hxx
+++ b/sd/source/ui/inc/ViewShell.hxx
@@ -317,7 +317,7 @@ public:
*/
::sd::WindowUpdater* GetWindowUpdater (void) const;
- /** Return the border that is drawn arround the actual document view.
+ /** Return the border that is drawn around the actual document view.
The border contains typically rulers and scroll bars.
@param bOuterResize
When this flag is <TRUE/> then the border is used for an
diff --git a/sd/source/ui/inc/Window.hxx b/sd/source/ui/inc/Window.hxx
index 56e0cb2a3429..57381e8a0949 100644
--- a/sd/source/ui/inc/Window.hxx
+++ b/sd/source/ui/inc/Window.hxx
@@ -51,7 +51,7 @@ public:
void SetViewShell (ViewShell* pViewSh);
/** Set the zoom factor to the specified value and center the display
- area arround the zoom center.
+ area around the zoom center.
@param nZoom
The zoom factor is given as integral percent value.
*/
diff --git a/sd/source/ui/inc/taskpane/ControlContainer.hxx b/sd/source/ui/inc/taskpane/ControlContainer.hxx
index c20d9eba5149..f0b5e2ba9e77 100644
--- a/sd/source/ui/inc/taskpane/ControlContainer.hxx
+++ b/sd/source/ui/inc/taskpane/ControlContainer.hxx
@@ -119,7 +119,7 @@ public:
is <FALSE/> the hidden controls are skipped.
@param bCycle
When this flag is <TRUE/> then the search for the previous
- control wraps arround when reaching the first control.
+ control wraps around when reaching the first control.
@return
Returns the index to the previous control or (sal_uInt32)-1 when
there is no previous control. This would be the case when there
@@ -141,7 +141,7 @@ public:
<FALSE/> the hidden controls are skipped.
@param bCycle
When this flag is <TRUE/> then the search for the next control
- wraps arround when reaching the last control.
+ wraps around when reaching the last control.
@return
Returns the index to the next control or (sal_uInt32)-1 when
there is no next control. This would be the case when there is
diff --git a/sd/source/ui/inc/taskpane/ScrollPanel.hxx b/sd/source/ui/inc/taskpane/ScrollPanel.hxx
index e73329bb9fb2..afd9c2071a9b 100644
--- a/sd/source/ui/inc/taskpane/ScrollPanel.hxx
+++ b/sd/source/ui/inc/taskpane/ScrollPanel.hxx
@@ -137,7 +137,7 @@ private:
const int mnHorizontalBorder;
/** List of horizontal stripes that is created from the gaps between
children when they are layouted. The stripes are painted in Paint()
- to fill the space arround the children.
+ to fill the space around the children.
*/
typedef ::std::vector< ::std::pair<int,int> > StripeList;
StripeList maStripeList;
diff --git a/sd/source/ui/inc/taskpane/SubToolPanel.hxx b/sd/source/ui/inc/taskpane/SubToolPanel.hxx
index 5c4054dde9a3..42bcdffcdfdb 100644
--- a/sd/source/ui/inc/taskpane/SubToolPanel.hxx
+++ b/sd/source/ui/inc/taskpane/SubToolPanel.hxx
@@ -45,7 +45,7 @@ namespace sd { namespace toolpanel {
is made transparent and painting it is done by this class. While
layouting its children it remembers the gaps between children and stores
them in maStripeList. In Paint() those gaps as well as the border
- arround all children are painted in the background color.</p>
+ around all children are painted in the background color.</p>
*/
class SubToolPanel
: public Control,
@@ -96,7 +96,7 @@ private:
const int mnHorizontalBorder;
/** List of horizontal stripes that is created from the gaps between
children when they are layouted. The stripes are painted in Paint()
- to fill the space arround the children.
+ to fill the space around the children.
*/
typedef ::std::vector< ::std::pair<int,int> > StripeList;
StripeList maStripeList;
diff --git a/sd/source/ui/sidebar/MasterPageContainer.cxx b/sd/source/ui/sidebar/MasterPageContainer.cxx
index 08542c173c9d..4edeeacebd0b 100644
--- a/sd/source/ui/sidebar/MasterPageContainer.cxx
+++ b/sd/source/ui/sidebar/MasterPageContainer.cxx
@@ -142,7 +142,7 @@ private:
bool mbFirstPageObjectSeen;
// The widths for the previews contain two pixels for the border that is
- // painted arround the preview.
+ // painted around the preview.
static const int SMALL_PREVIEW_WIDTH = 72 + 2;
static const int LARGE_PREVIEW_WIDTH = 2*72 + 2;
diff --git a/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx b/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx
index e1eaa4b1feb5..597f3ec6a251 100644
--- a/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx
+++ b/sd/source/ui/slidesorter/controller/SlsFocusManager.cxx
@@ -90,7 +90,7 @@ void FocusManager::MoveFocus (FocusMoveDirection eDirection)
{
if (mbIsVerticalWrapActive)
{
- // Wrap arround to the bottom row or the one above
+ // Wrap around to the bottom row or the one above
// and go to the correct column.
const sal_Int32 nLastIndex (nPageCount-1);
const sal_Int32 nLastColumn (nLastIndex % nColumnCount);
@@ -124,7 +124,7 @@ void FocusManager::MoveFocus (FocusMoveDirection eDirection)
{
if (mbIsVerticalWrapActive)
{
- // Wrap arround to the correct column.
+ // Wrap around to the correct column.
mnPageIndex = mnPageIndex % nColumnCount;
}
else
diff --git a/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx b/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
index e673725dd13d..868c6eefae8e 100644
--- a/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
+++ b/sd/source/ui/slidesorter/inc/controller/SlsFocusManager.hxx
@@ -62,11 +62,11 @@ public:
/** Move the focus from the currently focused page to one that is
displayed adjacent to it, either vertically or horizontally.
@param eDirection
- Direction in which to move the focus. Wrap arround is done
+ Direction in which to move the focus. Wrap around is done
differently when moving vertically or horizontally. Vertical
- wrap arround takes place in the same column, i.e. when you are
+ wrap around takes place in the same column, i.e. when you are
in the top row and move up you come out in the bottom row in the
- same column. Horizontal wrap arround moves to the next
+ same column. Horizontal wrap around moves to the next
(FMD_RIGHT) or previous (FMD_LEFT) page. Moving to the right
from the last page goes to the first page and vice versa.
When FMD_NONE is given, the current page index is checked for
diff --git a/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx b/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
index 0b8b8dc4247a..438b1cfea54e 100644
--- a/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
+++ b/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
@@ -44,7 +44,7 @@ class InsertPosition;
2.) Desired and minimal and maximal widths of page objects.
3.) Minimal and maximal number of columns.
4.) Vertical and horizontal gaps between objects in adjacent columns.
- 5.) Borders arround every page object.
+ 5.) Borders around every page object.
6.) Vertical and horizontal borders between enclosing page and outer
page objects.
From these it calculates various output values:
diff --git a/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx b/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx
index c64328acec5c..173106f3c5fa 100644
--- a/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx
+++ b/sd/source/ui/slidesorter/inc/view/SlsPageObjectViewObjectContact.hxx
@@ -92,7 +92,7 @@ public:
model::SharedPageDescriptor GetPageDescriptor (void) const;
/** Return the border widths in the screen coordinate system of the
- border arround the page object. The border contains frames for
+ border around the page object. The border contains frames for
selection, focus, the page name and number, and the indicator for
the page transition.
@param pDevice
diff --git a/sd/source/ui/tools/PreviewRenderer.cxx b/sd/source/ui/tools/PreviewRenderer.cxx
index 8d6933174bc6..ac9e9ee17adc 100644
--- a/sd/source/ui/tools/PreviewRenderer.cxx
+++ b/sd/source/ui/tools/PreviewRenderer.cxx
@@ -389,7 +389,7 @@ void PreviewRenderer::PaintFrame (void)
{
if (mbHasFrame)
{
- // Paint a frame arround the preview.
+ // Paint a frame around the preview.
Rectangle aPaintRectangle (
Point(0,0),
mpPreviewDevice->GetOutputSizePixel());
@@ -508,7 +508,7 @@ Image PreviewRenderer::ScaleBitmap (
mpPreviewDevice->SetMapMode (aMapMode);
mpPreviewDevice->SetOutputSize (aFrameSize);
- // Paint a frame arround the preview.
+ // Paint a frame around the preview.
mpPreviewDevice->SetLineColor (maFrameColor);
mpPreviewDevice->SetFillColor ();
mpPreviewDevice->DrawRect (Rectangle(Point(0,0), aFrameSize));
diff --git a/sd/source/ui/view/Outliner.cxx b/sd/source/ui/view/Outliner.cxx
index c59b1600ff59..1c7104aec8dd 100644
--- a/sd/source/ui/view/Outliner.cxx
+++ b/sd/source/ui/view/Outliner.cxx
@@ -419,7 +419,7 @@ bool Outliner::SpellNextDocument (void)
// found the loop is left through a break.
// It is the responsibility of the sd outliner object to correctly
// iterate over all text shapes, i.e. switch between views, wrap
- // arround at the end of the document, stop when all text shapes
+ // around at the end of the document, stop when all text shapes
// have been examined exactly once.
bool bFoundNextSentence = false;
while ( ! bFoundNextSentence)
@@ -581,7 +581,7 @@ void Outliner::Initialize (bool bDirectionIsForward)
}
else if (bOldDirectionIsForward != mbDirectionIsForward)
{
- // Requested iteration direction has changed. Turn arround the iterator.
+ // Requested iteration direction has changed. Turn around the iterator.
maObjectIterator.Reverse();
if (bIsAtEnd)
{
@@ -726,7 +726,7 @@ bool Outliner::SearchAndReplaceOnce (void)
{
mpDrawDocument->GetDocSh()->SetWaitCursor(false);
// The following loop is executed more then once only when a
- // wrap arround search is done.
+ // wrap around search is done.
while (true)
{
int nResult = pOutlinerView->StartSearchAndReplace(*mpSearchItem);
@@ -1071,7 +1071,7 @@ void Outliner::EndOfSearch (void)
ShowEndOfSearchDialog ();
mbEndOfSearch = true;
}
- // Ask the user whether to wrap arround and continue the search or
+ // Ask the user whether to wrap around and continue the search or
// to terminate.
else if (meMode==TEXT_CONVERSION || ShowWrapArroundDialog ())
{
@@ -1090,7 +1090,7 @@ void Outliner::EndOfSearch (void)
}
else
{
- // No wrap arround.
+ // No wrap around.
mbEndOfSearch = true;
}
}
@@ -1155,7 +1155,7 @@ bool Outliner::ShowWrapArroundDialog (void)
? STR_SAR_WRAP_BACKWARD
: STR_SAR_WRAP_BACKWARD_DRAW;
- // Pop up question box that asks the user whether to wrap arround.
+ // Pop up question box that asks the user whether to wrap around.
// The dialog is made modal with respect to the whole application.
QueryBox aQuestionBox (
NULL,
@@ -1454,7 +1454,7 @@ bool Outliner::HandleFailedSearch (void)
if (pOutlinerView != NULL && mpSearchItem != NULL)
{
// Detect whether there is/may be a prior match. If there is then
- // ask the user whether to wrap arround. Otherwise tell the user
+ // ask the user whether to wrap around. Otherwise tell the user
// that there is no match.
if (HasNoPreviousMatch ())
{
@@ -1466,7 +1466,7 @@ bool Outliner::HandleFailedSearch (void)
else
{
// No further matches found. Ask the user whether to wrap
- // arround and start again.
+ // around and start again.
bContinueSearch = ShowWrapArroundDialog ();
}
}
diff --git a/sw/source/filter/html/wrthtml.cxx b/sw/source/filter/html/wrthtml.cxx
index 451e35e18180..fb7481047ca5 100644
--- a/sw/source/filter/html/wrthtml.cxx
+++ b/sw/source/filter/html/wrthtml.cxx
@@ -661,7 +661,7 @@ static Writer& OutHTML_Section( Writer& rWrt, const SwSectionNode& rSectNd )
if( lcl_html_IsMultiColEnd( rHTMLWrt, nSectEndIdx-1 ) )
bEndTag = false;
- //.is there a columned section arround this one?
+ //.is there a columned section around this one?
const SwStartNode *pSttNd = rSectNd.StartOfSectionNode();
if( pSttNd )
{
diff --git a/toolkit/test/accessibility/Canvas.java b/toolkit/test/accessibility/Canvas.java
index 5c6fd0c4f3aa..116da3e12dbc 100644
--- a/toolkit/test/accessibility/Canvas.java
+++ b/toolkit/test/accessibility/Canvas.java
@@ -233,7 +233,7 @@ class Canvas
mnVOffset,
mnScale*aScreenSize.getWidth(),
mnScale*aScreenSize.getHeight());
- // Fill the screen rectangle and draw a frame arround it to increase its visibility.
+ // Fill the screen rectangle and draw a frame around it to increase its visibility.
g2.setColor (new Color (250,240,230));
g2.fill (aScreen);
g2.setColor (Color.BLACK);
diff --git a/sd/inc/Outliner.hxx b/sd/inc/Outliner.hxx
index d36fafce80e8..df538f3ab995 100644
--- a/sd/inc/Outliner.hxx
+++ b/sd/inc/Outliner.hxx
@@ -399,7 +399,7 @@ private:
/** Handle the situation that the iterator has reached the last object.
This may result in setting the <member>mbEndOfSearch</member> flag
back to </sal_False>. This method may show either the end-of-search
- dialog or the wrap-arround dialog.
+ dialog or the wrap-around dialog.
*/
void EndOfSearch (void);
@@ -409,7 +409,7 @@ private:
*/
void ShowEndOfSearchDialog (void);
/** Show a dialog that asks the user whether to wrap arround to the
beginning/end of the document and continue with the search/spell
check.
*/
@@ -488,7 +488,7 @@ private:
i.e. there is no match in the whole presentation, or when no further
match exists.
@return
- The returned value indicates whether another (wrapped arround)
+ The returned value indicates whether another (wrapped around)
search shall take place. If that is so, then it is the caller's
responsibility to set the cursor position accordingly.
*/
@@ -520,7 +520,7 @@ private:
/** Initiate the spell check of the next relevant text object.
When the outline view is active then this method is called
- after a wrap arround to continue at the beginning of the document.
+ after a wrap around to continue at the beginning of the document.
@return
Returns <TRUE/> to indicate that another call to this method is
required. When all text objects have been processed then
@@ -409,7 +409,7 @@ private:
*/
void ShowEndOfSearchDialog (void);
- /** Show a dialog that asks the user whether to wrap arround to the
+ /** Show a dialog that asks the user whether to wrap around to the
beginning/end of the document and continue with the search/spell
check.